﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;
using System.Collections.ObjectModel;

namespace test
{
    public partial class frmFontTest : Form
    {
        public frmFontTest()
        {
            InitializeComponent();
        }

        private void frmFontTest_Load(object sender, EventArgs e)
        {
            LoadDefaultMap();
            PlotFonts();
        }
        private void PlotFonts()
        {
            InMemoryFeatureLayer imfont = new InMemoryFeatureLayer();
            imfont.FeatureSource.Open();
            imfont.Columns.Add(new FeatureSourceColumn("Name"));

            PointStyle PFONT = new PointStyle(new GeoFont("ESRI Geology", 35, DrawingFontStyles.Bold), 82, new GeoSolidBrush(GeoColor.FromArgb(255,16,83,133)));
            PFONT.RotationAngle = 75;

            TextStyle tstyle = new TextStyle("Name", new GeoFont("CourierNew", 10, DrawingFontStyles.Bold), new GeoSolidBrush(GeoColor.SimpleColors.Red));
            tstyle.XOffsetInPixel = 15;
            tstyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
            tstyle.DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels;


            imfont.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(PFONT);
            imfont.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(tstyle);
            imfont.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            Feature fp = new Feature(BaseShape.CreateShapeFromWellKnownData("MULTIPOINT(73 23)"));
            fp.ColumnValues.Add("Name", "ABC");

            Feature fp1 = new Feature(BaseShape.CreateShapeFromWellKnownData("MULTIPOINT(74 23)"));

            imfont.InternalFeatures.Add(fp);
            imfont.InternalFeatures.Add(fp1);

            LayerOverlay l = new LayerOverlay();
            l.Layers.Add("TestLayer",imfont);
            wfMap.Overlays.Add(l);

            InMemoryFeatureSource imf = new InMemoryFeatureSource(imfont.FeatureSource.GetColumns(), imfont.FeatureSource.GetAllFeatures(ReturningColumnsType.AllColumns));
            imf.InternalFeatures.Add(fp);
               
            

        }
        //public new bool CanExecuteSqlQuery
        //{
        //    get
        //    {
        //        return true;
        //    }
        //}
        //public new bool CanModifyColumnStructure
        //{
        //    get
        //    {
        //        return true;
        //    }
        //}
        private void LoadDefaultMap()
        {
            try
            {
                wfMap.Overlays.Clear();
                wfMap.MapUnit = GeographyUnit.DecimalDegree;
                wfMap.ZoomLevelSnapping = ZoomLevelSnappingMode.None;
                GraticuleAdornmentLayer graticuleAdornmentLayer = new GraticuleAdornmentLayer();
                graticuleAdornmentLayer.Close();
                graticuleAdornmentLayer.Open();
                graticuleAdornmentLayer.GraticuleLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.SimpleColors.Silver, 0.001F, LineDashStyle.Dash, false);

                wfMap.AdornmentOverlay.Layers.Add("graticule", graticuleAdornmentLayer);

                wfMap.CurrentExtent = new RectangleShape(40, 35, 60, 20);
                wfMap.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.StandardColors.LightBlue);
                // wfMap.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);
                ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(Application.StartupPath + @"\Data\Countries02.shp");
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
                worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                LayerOverlay coverlay = new LayerOverlay();

                coverlay.Layers.Add("CountryLayer", worldLayer);
                wfMap.Overlays.Add(coverlay);

                wfMap.ZoomIn(80);
                wfMap.Refresh();

                //  PlotPtCircle();
            }
            catch (Exception err)
            {
                MessageBox.Show(err.Message, "");
            }
        }

       
        private void wfMap_MapClick(object sender, MapClickWinformsMapEventArgs e)
        {
            PointShape WorldPointR = ExtentHelper.ToWorldCoordinate(wfMap.CurrentExtent, e.ScreenX, e.ScreenY, wfMap.Width, wfMap.Height);
            Collection<Feature> cfeature = wfMap.FindFeatureLayer("TestLayer").FeatureSource.GetAllFeatures(ReturningColumnsType.AllColumns);
            MessageBox.Show(cfeature[0].ColumnValues["Name"].ToString() + cfeature[1].ColumnValues["Name"].ToString());
        }
    }
}
